@@ -38,12 +38,14 @@ from __future__ import print_function
 import os
 import subprocess
 import platform
+import locale
+import codecs
 
 def _read_stdout(cmd):
     try:
         pop = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         (std_out, std_err) = pop.communicate()
-        # Python 2.6 compatability
+        # Python 2.6 compatibility
         if isinstance(std_out, str):
             return std_out.strip()
         return std_out.decode(encoding='UTF-8').strip()
@@ -61,7 +63,7 @@ def read_issue(filename="/etc/issue"):
     :returns: list of strings in issue file, or None if issue file cannot be read/split
     """
     if os.path.exists(filename):
-        with open(filename, 'r') as f:
+        with codecs.open(filename, 'r', encoding=locale.getpreferredencoding()) as f:
             return f.read().split()
     return None
 
